@@ -1,4 +1,4 @@
-"""Custom ORM column types.
+"""Collection of custom column types.
 """
 
 import re
@@ -8,6 +8,12 @@ from sqlalchemy.types import SchemaType, TypeDecorator, Enum
 from ._compat import with_metaclass
 
 
+__all__ = [
+    'DeclarativeEnumType',
+    'DeclarativeEnum'
+]
+
+
 ##
 # Declarative Enum type
 # Adapted from the Enum Recipe:
@@ -17,8 +23,8 @@ from ._compat import with_metaclass
 class EnumSymbol(object):
     """Define a fixed symbol tied to a parent class."""
 
-    def __init__(self, cls_, name, value, description):
-        self.cls_ = cls_
+    def __init__(self, enum_class, name, value, description):
+        self.enum_class = enum_class
         self.name = name
         self.value = value
         self.description = description
@@ -27,7 +33,7 @@ class EnumSymbol(object):
         """Allow unpickling to return the symbol linked to the DeclarativeEnum
         class.
         """
-        return getattr, (self.cls_, self.name)
+        return getattr, (self.enum_class, self.name)
 
     def __iter__(self):
         return iter([self.value, self.description])
@@ -46,13 +52,13 @@ class EnumSymbol(object):
 class EnumMeta(type):
     """Generate new DeclarativeEnum classes."""
 
-    def __init__(cls, classname, bases, dict_):
-        cls._reg = reg = cls._reg.copy()
-        for k, v in dict_.items():
-            if isinstance(v, tuple):
-                sym = reg[v[0]] = EnumSymbol(cls, k, *v)
-                setattr(cls, k, sym)
-        type.__init__(cls, classname, bases, dict_)
+    def __init__(cls, classname, bases, dct):
+        cls._reg = cls._reg.copy()
+        for name, value in dct.items():
+            if isinstance(value, tuple):
+                sym = cls._reg[value[0]] = EnumSymbol(cls, name, *value)
+                setattr(cls, name, sym)
+        type.__init__(cls, classname, bases, dct)
 
     def __iter__(cls):
         return iter(cls._reg.values())
@@ -63,12 +69,10 @@ class DeclarativeEnumType(SchemaType, TypeDecorator):
 
     def __init__(self, enum):
         self.enum = enum
-        self.impl = Enum(
-            *enum.values(),
-            name="ck%s" % re.sub('([A-Z])',
-                                 lambda m: "_" + m.group(1).lower(),
-                                 enum.__name__)
-        )
+        constraint = 'ck{0}'.format(re.sub('([A-Z])',
+                                           lambda m: '_' + m.group(1).lower(),
+                                           enum.__name__))
+        self.impl = Enum(*enum.values(), name=constraint)
 
     def _set_table(self, table, column):
         self.impl._set_table(table, column)
@@ -88,25 +92,42 @@ class DeclarativeEnumType(SchemaType, TypeDecorator):
 
 
 class DeclarativeEnum(with_metaclass(EnumMeta, object)):
-    """Declarative enumeration."""
+    """Declarative enumeration.
+
+    For example::
+
+        class OrderStatus(DeclarativeEnum):
+            pending = ('p', 'Pending')
+            submitted = ('s', 'Submitted')
+            complete = ('c', 'Complete')
+
+        class Order(Model):
+            status = Column(OrderStatus.db_type(), default=OrderStatus.pending)
+    """
 
     _reg = {}
 
     @classmethod
     def from_string(cls, string):
-        """Get enum value from string"""
+        """Return enum symbol given string value.
+
+        Raises:
+            ValueError: If `string` doesn't correspond to an enum value.
+        """
         try:
             return cls._reg[string]
         except KeyError:
-            raise ValueError(
-                "Invalid value for %r: %r" % (cls.__name__, string))
+            raise ValueError('Invalid value for %r: %r' % (cls.__name__,
+                                                           string))
 
     @classmethod
     def values(cls):
-        """Return enumeration values."""
+        """Return list of possible enum values. Each value is a valid argument
+        to :meth:`from_string`.
+        """
         return cls._reg.keys()
 
     @classmethod
     def db_type(cls):
-        """Provide database column type for use in table column definitions."""
+        """Return database column type for use in table column definitions."""
         return DeclarativeEnumType(cls)
